elisa: Elisa absorbance readings

elisaR Documentation

Elisa absorbance readings

Description

A dataset was collected consisting of eight ELISA absorbance readings, each corresponding to a different, increasing concentration of a substrate. The primary focus of the analysis is to characterize the relationship between substrate concentration and measured absorbance, facilitating calibration or interpretation of ELISA response as a function of substrate level.

Usage

elisa

Format

A data frame with 3 variables: DUnit, Concentration, Absorbance.

DUnit

Factor. Unique identifier for each ELISA reading.

Concentration

Numeric. Substrate concentration used for each reading.

Absorbance

Numeric. ELISA absorbance value measured at the given substrate concentration.

Welham, S. J., Gezan, S. A., Clark, S. J., and Mead, A. (2015) Statistical Methods in Biology: Design and analysis of experiments and regression

Examples

summary(lm(Absorbance ~ log10(Concentration + 1), data = elisa))


smbdata documentation built on Jan. 20, 2026, 5:06 p.m.