| willow | R Documentation |
A sample of 50 willow beetles (Phratora vulgatissima) was collected from a willow crop near Bristol, UK, to investigate morphological variation within the population. For each beetle, measurements were taken of total body length and width, among other characteristics. This dataset enables analysis of size variation and potential relationships between morphological traits in willow beetles from this location.
willow
A data frame with 3 variables: DBeetle, Length, Width.
Factor. Unique identifier for each beetle in the sample.
Numeric. Total body length of the beetle (in millimeters, mm).
Numeric. Maximum body width of the beetle (in millimeters, mm).
Welham, S. J., Gezan, S. A., Clark, S. J., and Mead, A. (2015) Statistical Methods in Biology: Design and analysis of experiments and regression
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.